@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "consult" "20260105.1624"
-  "Consulting completing-read."
+(define-package "consult" "20260118.744"
+  "Search and navigate via completing-read."
   '((emacs  "29.1")
     (compat "30"))
   :url "https://github.com/minad/consult"
-  :commit "4ca98db03dac33476d60657ba975639ee30f2e9e"
-  :revdesc "4ca98db03dac"
+  :commit "312f2db1a23ef5428ab9553679147d5ff3a4e57d"
+  :revdesc "312f2db1a23e"
   :keywords '("matching" "files" "completion")
   :maintainers '(("Daniel Mendler" . "mail@daniel-mendler.de")))
